@@ -2,6 +2,9 @@
 
 __author__ = """George Tzanetakis"""
 __email__ = 'gtzan@cs.uvic.ca'
-__version__ = '0.1.0'
+__version__ = '0.6.0'
 
 
+
+from .boreal import * 
+from .audio_widgets import * 
